<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Ešte stále existuje život aj mimo prehliadač!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Verzia %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licencované pre: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 je plne slobodným softvérom, ktorého vývoj si však žiada značnú dávku času.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Preto prosím o akúkoľvek finančnú &lt;a href=&apos;%1&apos;&gt;podporu&lt;/a&gt;  pri pokračujúcom vývoji %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Prelož %1 do svojho materinského jazyka cez %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikonu nadizajnoval %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Vydané pod &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zatvoriť</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O projekte</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Vlož svoje licenčné detaily</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;E-mail:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Kód:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Prosím licencujte %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Demoverzia expirovala.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Plná verzia vám umožňuje pozerať videá bez prerušení.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Aplikácia bez licencie expiruje za %1 dní.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Zakúpením plnej verzie tiež podporíš vynaložené úsilie pri tvorbe %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Použiť demo</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Vložiť licenciu</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Zakúpiť licenciu</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Od %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Všetky videá</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Neprezreté videá</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Meno</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Naposledy aktualizované</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Naposledy pridané</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Naposledy prezerané</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Najviac prezerané</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Zoradiť podľa</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Označiť všetky ako zhliadnuté</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Zobraziť aktualizované</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Nemáš žiadne subskripcie. Použi symbol hviezdy pre odoberanie kanálov.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Všetky videá</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Neprezreté videá</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Označiť ako už videné</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Zrušiť odber</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Nie sú k dispozícii žiadne aktualizované subskripcie.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Práve teraz</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 prezretí</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bajtov</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bajtov/sek</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/sek</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/sek</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekúnd</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minút</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>zostáva %4 %5</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 stiahnuté za %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Sťahovanie ukončené.</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Zmeniť umiestnenie...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Zmeniť umiestnenie sťahovaní</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Umiestnenie sťahovaní zmenené.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Aktuálne sťahovania sa uložia ešte na predchádzajúcom umiestnení.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Sťahujem do: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Sťahovania</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Spustiteľný súbor bol pravdepodobne upravený vírusom.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 sa nespustí. Skúste inštalovať znova.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Ukončiť</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Preinštalovať</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Prehrať</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pozastaviť</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Prehrať/Pozastaviť</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastaviť</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Zastav hranie po aktuálnom videu</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Nasledovné video</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Predošlé video</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Zvýšiť hlasitosť</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Znížiť hlasitosť</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Stlmiť</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Pretočiť vpred</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Pretočiť vzad</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Hľadať</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Nájsť videá a kanály podľa kľúča</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Prehliadať</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Prehliadať videá podľa kategórie</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Subskripcie</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Odber kanálov</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Daj sa do pohody</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Okno</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimalizovať</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Zastaviť</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Zastaviť prehrávanie a vrátiť sa k výsledkom hľadania</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>&amp;Predošlé</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Ísť na predošlé video</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Preskočiť</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Preskočiť na nasledovné video</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Prehrať</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Obnoviť prehrávanie</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Celá obrazovka</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Na celú obrazovku</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Kompaktný mód</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Skryť playlist a nástrojovú lištu</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Otvoriť &amp;YouTube stránku</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Prejsť na YouTube stránku videa a pozastaviť prehrávanie</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Kopírovať &amp;odkaz z YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopírovať YouTube odkaz aktuálneho videa do schránky</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Kopírovať &amp;URL video streamu</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopírovať odkaz aktuálneho video streamu do schránky</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Nájsť zvyšné relevantné &amp;časti</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Pokúsiť sa nájsť zvyšné video časti</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Odstrániť</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Odstrániť vybrané videá z playlistu</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Presunúť &amp;nahor</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Presunúť vybrané videá v playliste nahor</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Presunúť &amp;nadol</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Presunúť vybrané videá v playliste nadol</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Vyčistiť zoznam posledných hľadaní</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Vyčisiť históriu hľadania. Nevratná akcia.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončiť</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Maj sa</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Domovská stránka</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na Internete</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Finančne &amp;podporiť</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Podpor prosím pokračujúci vývoj %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O projekte</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informácie o %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hľadať</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Stlmiť hlasitosť</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;Manuálne prehrávanie</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Koniec manuálneho prehrávania</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Sťahovania</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Zobraziť detaily o sťahovaní</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Stiahnuť</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Stiahnuť aktuálne video</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>&amp;Snímka obrazovky</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Odoberať daný kanál</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Zdieľať aktuálne video cez %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;E-mail</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mailová adresa</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zatvoriť</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Vždy na vrchu</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Zastav po tomto videu</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Nahlásiť problém...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Upraviť kritériá hľadania...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Viac...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Pridružené vidá</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Pozerať videá pridružené k aktuálnemu</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Otvoriť v prehliadači...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>%Páči sa vám %1? ohodnoťte ho!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Zakúpiť %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplikácia</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Prehrávanie</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Playlist</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Zdieľanie</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Zobrazenie</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Nápoveda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Stlač %1 pre zvýšenie hlasitosti, %2 pre jej zníženie</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Vybrať svoju obsahovú lokáciu</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Otváram %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Chceš ukončiť %1 aj napriek prebiehajúcemu sťahovaniu?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Pokiaľ teraz ukončíš %1, prídeš o aktuálne sťahovanie.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Zatvoriť a zrušiť sťahovanie</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Počkať kým skončí sťahovanie</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Chyba: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pozasaviť</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pozastaviť prehrávanie</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Načítava sa...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Opustiť režim &amp;celej obrazovky</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Zostávajúci čas: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Hlasitosť na %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Hlasitosť stlmená</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Hlasitosť nie je stlmená</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Maximálne rozlíšenie videa nastavené na %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Nemaj obavy o súkromie</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Sťahovanie kompletné</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 verzie %2 je k dispozícii.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Pripomenúť neskôr</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualizácia</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Takto môžeš prilepiť YouTube odkaz do inej aplikácie</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Budeš môcť prilepiť odkaz video streamu do inej aplikácie</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Odkaz bude platný len obmedzenú dobu.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Sťahujem %1.</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>z</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>časť</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>epizóda</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Odoslané z %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Zrušiť odber z %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Odoberať z %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Bol zrušený odber kanála %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Odoberáte kanál %1</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Nová verzia %1 je práve dostupná!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 je práve dostupná. Máš %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Chceš ju stiahnuť?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Preskočiť túto verziu</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Pripomenúť mi neskôr</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Nainštalovať aktualizáciu</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Vložiť</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 z %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Pripravujem</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Zlyhané</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Úspešné</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Zastavené</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Zastav sťahovanie</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Zobraz v %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Otvor nadradený adresár</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Opakuj sťahovanie</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Zobraz %1 viac</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Žiadne videá</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Niet viac videí</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Zoradiť podľa</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Relevancia</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Počet zhliadnutí</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Hodnotenie</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Kedykoľvek</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Dnes</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 dní</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 dní</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Dĺžka</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Všetko</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Krátky</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Stredný</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Dlhý</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Menej ako 4 minúty</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Medzi 4 a 20 minútami</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Viac ako 20 minút</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalita</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Vysoké rozlíšenie</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p alebo vyššie</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Hotovo</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Hotovo</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Hľadať</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Vitaj v aplikácii &lt;a href=&apos;%1&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>pre spustenie sledovania.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>kľúčové slovo</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Vlož</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Posledné kľúčové slová</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Posledné kanály</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Získať plnú verziu</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Späť</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Vpred k %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Späť k %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Upraviť kritériá hľadania</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Mali ste na mysli: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Zmeniť umiestnenie...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Snímka obrazovky uložená v %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Úložisko snímok obrazovky zmenené.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Najpopulárnejšie</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Sťahujem aktualizáciu...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Alžirsko</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentína</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Austrália</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgicko</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brazília</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Kanada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Čile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Kolumbia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Česká Republika</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egypt</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Francúzsko</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Nemecko</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Grécko</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Maďarsko</translation>
    </message>
    <message>
        <source>India</source>
        <translation>India</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonézia</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Írsko</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Izrael</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Taliansko</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japonsko</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordánsko</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Keňa</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malajzia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Mexiko</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Maroko</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Holandsko</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Nový Zéland</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigéria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filipíny</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Poľsko</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rusko</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Saudská Arábia</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapur</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Južná Afrika</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Južná Kórea</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Španielsko</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Švédsko</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunisko</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turecko</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Spojené Arabské Emiráty</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Veľká Británia</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Jemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Celosvetovo</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Nedostupný video stream pre %1</translation>
    </message>
</context>
</TS>